==> Clarity_SDK-1.0.4.tar.gz: Clarity_SDK-1.0.4/README.md <==
---
title: Getting Started
---
​
## Getting Started
​
### Create an account and subscribe to APIs
​
To use any of our APIs you must create a developer account. A developer account provides an API Key for accessing our APIs, a playground for testing our APIs, and API usage metrics. Create or sign in using the buttons in the top right.
​
After you create a new account, you will have a new API Key but it won't be linked to any of our APIs. To activate it for a particular API, navigate to [APIs](/apis) and find the API you want. Click `subscribe`. Your API Key is now subscribed to the API and you can make calls to its methods.
​
Depending on the API configuration, subscribing to one API may subscribe you to several APIs. These APIs may have related functionality or share a pricing plan. Requests against any of them will be counted together in your usage.
​
We know that figuring out how to use APIs can be hard. Use the “Try it out!” feature to get examples of the request and response shapes of our APIs. This makes an API call to the backend service using your API Key and provides a sample `curl` request with all necessary input parameters and the real response.
​
Additional code examples and documentation can be found at the [Intuli](https://www.intuli.com) product page for your API subscriptions. You can also find the SDK documentation below.
​
If you need your API Key for any reason, you can always find it on [your dashboard](/dashboard) after logging in.
----
#### Clarity SDK Documentation
​
| Framework | Download Link                                              |
|------------|---------------------------------------------------------------------------------------------------------|
| Javascript | [Download](https://www.intuli.com/wp-content/uploads/2018/12/Clarity-Javascript-SDK-Documentation.docx) |
| .Net    | [Download](https://www.intuli.com/wp-content/uploads/2018/12/Clarity-NET-SDK-Documentation.docx)    |
| Python   | [Download] (https://pypi.org/project/Clarity-SDK/) |                                                |
​
​
​
----
### Monitor your usage
​
Typically each API has a usage limit set for each API Key. As you scale up your usage of the APIs, you can monitor your usage towards the limits on [your dashboard](/dashboard).
Collapse

==> Clarity_SDK-1.0.6.tar.gz: Clarity_SDK-1.0.6/README.md <==
# Getting Started

----
## Create an account and subscribe to APIs
To use any of our APIs you must create a developer account. A developer account provides an API Key for accessing our APIs, a playground for testing our APIs, and API usage metrics. Create or sign in using the buttons in the top right.
​
After you create a new account, you will have a new API Key but it won't be linked to any of our APIs. To activate it for a particular API, navigate to [APIs](/apis) and find the API you want. Click `subscribe`. Your API Key is now subscribed to the API and you can make calls to its methods.
​
Depending on the API configuration, subscribing to one API may subscribe you to several APIs. These APIs may have related functionality or share a pricing plan. Requests against any of them will be counted together in your usage.
​
We know that figuring out how to use APIs can be hard. Use the “Try it out!” feature to get examples of the request and response shapes of our APIs. This makes an API call to the backend service using your API Key and provides a sample `curl` request with all necessary input parameters and the real response.
​
Additional code examples and documentation can be found at the [Intuli](https://www.intuli.com) product page for your API subscriptions. You can also find the SDK documentation below.
​
If you need your API Key for any reason, you can always find it on [your dashboard](/dashboard) after logging in.

----
### Clarity SDK Documentation
* NET - [Download](https://www.intuli.com/wp-content/uploads/2018/12/Clarity-NET-SDK-Documentation.docx)
* JS - [Download](https://www.intuli.com/wp-content/uploads/2018/12/Clarity-Javascript-SDK-Documentation.docx)
* Python - [Download] (https://pypi.org/project/Clarity-SDK/)

----
### Monitor your usage
​
Typically each API has a usage limit set for each API Key. As you scale up your usage of the APIs, you can monitor your usage towards the limits on [your dashboard](/dashboard).
Collapse
​
